@@ -4,8 +4,7 @@
 #'
 #' @return data.frame
 GETcontent<-function(...){
-  Sys.sleep(1.6)
-  resp<-httr::GET(...)
+  resp<-get(...)
   code<-httr::status_code(resp)
   content<-httr::content(resp ,as="text"
                          ,encoding="utf-8")
@@ -13,3 +12,8 @@ GETcontent<-function(...){
   if(code==200) res<-jsonlite::fromJSON(content)
   return(res)
 }
+
+get <- ratelimitr::limit_rate(
+  httr::GET,
+  ratelimitr::rate(n = 1, period = 1.5)
+)
